@@ -19,7 +19,7 @@
  under the License.
 */
 ;(function() {
-var PLATFORM_VERSION_BUILD_LABEL = '3.1.0';
+var PLATFORM_VERSION_BUILD_LABEL = '4.0.0';
 // file: src/scripts/require.js
 var require;
 var define;
@@ -975,7 +975,7 @@ module.exports = function (success, fail, service, action, args) {
             const callbackId = service + cordova.callbackId++;
 
             if (typeof success === 'function' || typeof fail === 'function') {
-                cordova.callbacks[callbackId] = { success: success, fail: fail };
+                cordova.callbacks[callbackId] = { success, fail };
             }
             try {
                 // callbackOptions param represents additional optional parameters command could pass back, like keepCallback or
